<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>AddAppDialog</name>
    <message>
        <location filename="addappdialog.ui" line="23"/>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="33"/>
        <source>Categories</source>
        <translation>Categorías</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="45"/>
        <source>Add category</source>
        <translation>Agregar categorías</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="59"/>
        <source>Delete category</source>
        <translation>Borrar categorías</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="76"/>
        <source>Command:</source>
        <translation>Orden:</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="121"/>
        <source>Save Changes</source>
        <translation>Guardar cambios</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="128"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="166"/>
        <source>Quit dialog</source>
        <translation>Cerrar diálogo</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="169"/>
        <location filename="addappdialog.cpp" line="103"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="176"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="194"/>
        <source>Select...</source>
        <translation>Seleccionar...</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="201"/>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="208"/>
        <source>Comment:</source>
        <translation>Comentario:</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="215"/>
        <source>Icon:</source>
        <translation>Ícono:</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="222"/>
        <location filename="addappdialog.cpp" line="122"/>
        <source>Set icon</source>
        <translation>Ajustar ícono</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="235"/>
        <source>Run in Terminal</source>
        <translation>Ejecutar en terminal</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="248"/>
        <source>Startup Notifier</source>
        <translation>Nortificador de inicio</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="37"/>
        <source>Add Custom Application</source>
        <translation>Agregar aplicaciones personalizadas</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="54"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="54"/>
        <source>Could not save the file</source>
        <translation>No se pudo guardar el archivo</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="103"/>
        <source>Save changes?</source>
        <translation>¿Guardar los cambios?</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="103"/>
        <source>Do you want to save your edits?</source>
        <translation>¿Desea guardar sus cambios?</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="103"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="17"/>
        <location filename="mainwindow.cpp" line="835"/>
        <source>MX Menu Editor</source>
        <translation>MX Editor del Menú</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="33"/>
        <source>Advanced Editor</source>
        <translation>Editor avanzado</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="54"/>
        <source>Categories and applications</source>
        <translation>Categorías y aplicaciones</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="81"/>
        <source>Add custom application</source>
        <translation>Agregar aplicaciones personalizadas</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="95"/>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="104"/>
        <source>Run in terminal</source>
        <translation>Ejecutar en terminal</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="114"/>
        <source>Hide</source>
        <translation>Ocultar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="124"/>
        <source>Notify startup</source>
        <translation>Notificar inicio</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="147"/>
        <source>Quick Editor</source>
        <translation>Editor rápido</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="159"/>
        <source>Comment:</source>
        <translation>Comentario:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="169"/>
        <source>Restore original item</source>
        <translation>Restaurar ítem original</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="180"/>
        <source>Command:</source>
        <translation>Orden:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="190"/>
        <source>Select...</source>
        <translation>Seleccionar...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="204"/>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="225"/>
        <source>Icon</source>
        <translation>Ícono</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="265"/>
        <location filename="mainwindow.cpp" line="537"/>
        <source>Change icon</source>
        <translation>Cambiar ícono</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="279"/>
        <source>Categories</source>
        <translation>Categorías</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="291"/>
        <source>Add</source>
        <translation>Agregar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="305"/>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="371"/>
        <source>Quit application</source>
        <translation>Terminar aplicación</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="374"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="381"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="422"/>
        <source>Display help</source>
        <translation>Mostrar ayuda</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="425"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="432"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="451"/>
        <source>Save Changes</source>
        <translation>Guardar cambios</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="458"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="493"/>
        <source>About this application</source>
        <translation>Acerca de esta aplicación</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="496"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="503"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="458"/>
        <source>Select executable file</source>
        <translation>Seleccionar archivo ejecutable</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="521"/>
        <source>Image Files (*.png *.jpg *.bmp *.xpm)</source>
        <translation>Archivos de imagen (*.png *.jpg *.bmp *.xpm)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="714"/>
        <source>Choose category</source>
        <translation>Escoger categoría</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="725"/>
        <location filename="mainwindow.cpp" line="841"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="726"/>
        <source>OK</source>
        <translation>Está bien</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="816"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="816"/>
        <source>Could not save the file</source>
        <translation>No se pudo guardar el archivo</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="834"/>
        <source>About MX Menu Editor</source>
        <translation>Acerca de MX Editor del menú</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="835"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="836"/>
        <source>Program for editing Xfce menu</source>
        <translation>Programa para editar el menú de Xfce</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="838"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="839"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="840"/>
        <source>Changelog</source>
        <translation>Registro de cambios</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="856"/>
        <source>&amp;Close</source>
        <translation>&amp;Close</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="902"/>
        <source>Save changes?</source>
        <translation>¿Guardar los cambios?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="902"/>
        <source>Do you want to save your edits?</source>
        <translation>¿Desea guardar sus cambios?</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="main.cpp" line="51"/>
        <source>You must run this program as normal user.</source>
        <translation>Debe ejecutar este programa como un usuario normal.</translation>
    </message>
</context>
</TS>